/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IChannelStorageService } from "@fluidframework/datastore-definitions";
import { IGarbageCollectionData, ISummaryTreeWithStats, ITelemetryContext } from "@fluidframework/runtime-definitions";
import { ICodecOptions, IJsonCodec } from "../codec/index.js";
import { ChangeEncodingContext, ChangeFamily, ChangeFamilyEditor, EncodedRevisionTag, RevisionTag } from "../core/index.js";
import { SchemaAndPolicy } from "../feature-libraries/index.js";
import { Summarizable, SummaryElementParser, SummaryElementStringifier } from "./sharedTreeCore.js";
import { EditManager } from "./editManager.js";
/**
 * Provides methods for summarizing and loading an `EditManager`
 */
export declare class EditManagerSummarizer<TChangeset> implements Summarizable {
    private readonly editManager;
    private readonly schemaAndPolicy?;
    readonly key = "EditManager";
    private readonly codec;
    constructor(editManager: EditManager<ChangeFamilyEditor, TChangeset, ChangeFamily<ChangeFamilyEditor, TChangeset>>, revisionTagCodec: IJsonCodec<RevisionTag, EncodedRevisionTag, EncodedRevisionTag, ChangeEncodingContext>, options: ICodecOptions, schemaAndPolicy?: SchemaAndPolicy | undefined);
    getAttachSummary(stringify: SummaryElementStringifier, fullTree?: boolean, trackState?: boolean, telemetryContext?: ITelemetryContext): ISummaryTreeWithStats;
    summarize(stringify: SummaryElementStringifier, fullTree?: boolean, trackState?: boolean, telemetryContext?: ITelemetryContext): Promise<ISummaryTreeWithStats>;
    private summarizeCore;
    getGCData(fullGC?: boolean): IGarbageCollectionData;
    load(services: IChannelStorageService, parse: SummaryElementParser): Promise<void>;
}
//# sourceMappingURL=editManagerSummarizer.d.ts.map