/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/**
 * Indicates that an object is a flex tree.
 * @internal
 */
export const flexTreeMarker = Symbol("flexTreeMarker");
export function isFlexTreeEntity(t) {
    return typeof t === "object" && t !== null && flexTreeMarker in t;
}
export function isFlexTreeNode(t) {
    return isFlexTreeEntity(t) && t[flexTreeMarker] === FlexTreeEntityKind.Node;
}
/**
 * @internal
 */
export var FlexTreeEntityKind;
(function (FlexTreeEntityKind) {
    FlexTreeEntityKind[FlexTreeEntityKind["Node"] = 0] = "Node";
    FlexTreeEntityKind[FlexTreeEntityKind["Field"] = 1] = "Field";
})(FlexTreeEntityKind || (FlexTreeEntityKind = {}));
/**
 * Status of the tree that a particular node belongs to.
 * @public
 */
export var TreeStatus;
(function (TreeStatus) {
    /**
     * Is parented under the root field.
     */
    TreeStatus[TreeStatus["InDocument"] = 0] = "InDocument";
    /**
     * Is not parented under the root field, but can be added back to the original document tree.
     */
    TreeStatus[TreeStatus["Removed"] = 1] = "Removed";
    /**
     * Is removed and cannot be added back to the original document tree.
     */
    TreeStatus[TreeStatus["Deleted"] = 2] = "Deleted";
})(TreeStatus || (TreeStatus = {}));
/**
 * {@inheritdoc TreeNode.[onNextChange]}
 * @internal
 */
export const onNextChange = Symbol("onNextChange");
/**
 * Reserved object node field property names to avoid collisions with the rest of the object node API.
 * @internal
 */
export const reservedObjectNodeFieldPropertyNames = [
    "constructor",
    "context",
    "is",
    "on",
    "parentField",
    "schema",
    "treeStatus",
    "tryGetField",
    "type",
    "value",
    "localNodeKey",
    "boxedIterator",
    "iterator",
];
/**
 * Reserved object node field property names prefixes.
 * These are reserved to avoid collisions with properties derived from field other field names.
 *
 * Field names starting with these must be followed by a lowercase letter, or be escaped.
 * @internal
 */
export const reservedObjectNodeFieldPropertyNamePrefixes = [
    "set",
    "boxed",
    "field",
    "Field",
];
// #endregion
//# sourceMappingURL=flexTreeTypes.js.map