/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IEditableForest, TreeStoredSchemaSubscription } from "../core/index.js";
/**
 * Configuration for the forest test suite.
 */
export interface ForestTestConfiguration {
    suiteName: string;
    factory: (schema: TreeStoredSchemaSubscription) => IEditableForest;
    /**
     * If true, skip the tests that ensure errors are thrown when applying deltas without clearing cursors.
     *
     * @remarks Errors from current cursors during edits are not required by the Forest API specification,
     * but are nice for debugging.
     * Performance oriented forest implementations may opt out of this check.
     * Applications wanting help debugging invalid forest API use should use cursors that include this check.
     */
    skipCursorErrorCheck?: true;
}
/**
 * Generic forest test suite
 */
export declare function testForest(config: ForestTestConfiguration): void;
//# sourceMappingURL=forestTestSuite.d.ts.map