/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { JsonCompatibleReadOnly } from "../../util/index.js";
export declare function takeJsonSnapshot(data: JsonCompatibleReadOnly, suffix?: string): void;
/**
 * @param data - content to save and compare. Must be deterministic.
 * @param suffix - appended to file name. For example ".txt" or ".json"
 * @param compare - given the before and after strings and throws an error if they differ.
 * This cannot be used to suppress errors for non-deterministic input: it can only be used to provide nicer error messages.
 *
 * Non-deterministic data is forbidden (and will error after compare is run) to prevent unneeded changes/churn of snapshot files when regenerating,
 * as well as to ensure that buggy compare functions can't falsy pass tests.
 */
export declare function takeSnapshot(data: string, suffix: string, compare?: (actual: string, expected: string, message: string) => void): void;
/**
 * Delete the existing test file directory and recreate it.
 *
 * If the directory does not already exist, this will create it.
 *
 * @param dirPath - The path within the `snapshots` directory.
 */
export declare function useSnapshotDirectory(dirPath?: string): void;
//# sourceMappingURL=snapshotTools.d.ts.map